@@ -27,7 +27,7 @@
  ************************************************************************/
 
 #include <malloc.h>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #include <rtl/alloc.h>
 #include <osl/mutex.hxx>
@@ -187,7 +187,7 @@ namespace
         (*pThis->getUnoI()->pDispatcher)(
           pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 
-        // in case an exception occured...
+        // in case an exception occurred...
         if (pUnoExc)
         {
             // destruct temporary in/inout params
@@ -208,7 +208,7 @@ namespace
             // is here for dummy
             return typelib_TypeClass_VOID;
         }
-        else // else no exception occured...
+        else // else no exception occurred...
         {
             // temporary params
             for ( ; nTempIndizes--; )
@@ -289,7 +289,7 @@ namespace
         if (nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex)
         {
             throw RuntimeException(
-                OUString::createFromAscii("illegal vtable index!"),
+                OUString( RTL_CONSTASCII_USTRINGPARAM( "illegal vtable index!" )),
                 (XInterface *)pCppI );
         }
         
@@ -388,7 +388,7 @@ namespace
         default:
         {
             throw RuntimeException(
-                OUString::createFromAscii("no member description found!"),
+                OUString( RTL_CONSTASCII_USTRINGPARAM( "no member description found!" )),
                 (XInterface *)pCppI );
             // is here for dummy
             eRet = typelib_TypeClass_VOID;
