@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,7 +31,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #include <rtl/alloc.h>
 #include <osl/mutex.hxx>
@@ -198,7 +199,7 @@ static typelib_TypeClass cpp2uno_call(
     // invoke uno dispatch call
     (*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
     
-    // in case an exception occured...
+    // in case an exception occurred...
     if ( pUnoExc )
     {
         // destruct temporary in/inout params
@@ -217,7 +218,7 @@ static typelib_TypeClass cpp2uno_call(
         // is here for dummy
         return typelib_TypeClass_VOID;
     }
-    else // else no exception occured...
+    else // else no exception occurred...
     {
         // temporary params
         for ( ; nTempIndizes--; )
@@ -291,7 +292,7 @@ extern "C" typelib_TypeClass cpp_vtable_call(
     OSL_ENSURE( nFunctionIndex < pTypeDescr->nMapFunctionIndexToMemberIndex, "### illegal vtable index!\n" );
     if ( nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex )
     {
-        throw RuntimeException( OUString::createFromAscii("illegal vtable index!"),
+        throw RuntimeException( OUString(RTL_CONSTASCII_USTRINGPARAM("illegal vtable index!")),
                                 reinterpret_cast<XInterface *>( pCppI ) );
     }
 
@@ -388,7 +389,7 @@ extern "C" typelib_TypeClass cpp_vtable_call(
         }
         default:
         {
-            throw RuntimeException( OUString::createFromAscii("no member description found!"),
+            throw RuntimeException( OUString(RTL_CONSTASCII_USTRINGPARAM("no member description found!")),
                                     reinterpret_cast<XInterface *>( pCppI ) );
             // is here for dummy
             eRet = typelib_TypeClass_VOID;
@@ -518,3 +519,5 @@ void bridges::cpp_uno::shared::VtableFactory::flushCode(
     unsigned char const *, unsigned char const * )
 {
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
