@@ -187,106 +187,6 @@ struct tm *gmtime_r(const time_t *timep, struct tm *buffer)
 }
 #endif  /* defined NETBSD */
 
-#ifdef SCO
-#include <pwd.h>
-#include <shadow.h>
-#include <sys/types.h>
-
-struct spwd *getspnam_r(const char *name, struct spwd* s, char* buffer, int size )
-{
-      struct spwd* res;
-
-      pthread_mutex_lock(&getrtl_mutex);
-
-      if ( res = getspnam(name) )
-      {
-        int nnamp;
-
-        nnamp = strlen(res->sp_namp)+1;
-
-        if (nnamp+strlen(res->sp_pwdp) < size) {
-            memcpy(s, res, sizeof(struct spwd));
-
-            strcpy(buffer, res->sp_namp);
-              s->sp_namp = buffer;
-            buffer += nnamp;
-
-            strcpy(buffer, res->sp_pwdp);
-              s->sp_pwdp = buffer;
-
-               res = s;
-        } 
-        else 
-            res = 0;
-    }
-
-      pthread_mutex_unlock(&getrtl_mutex);
-
-      return res;
-}
-
-struct passwd *getpwnam_r(const char* name, struct passwd* s, char* buffer, int size )
-{
-      struct passwd* res;
-
-      pthread_mutex_lock(&getrtl_mutex);
-
-      if ( res = getpwnam(name) )
-      {
-        int nname, npasswd, nage;
-        int ncomment, ngecos, ndir;
-
-        nname= strlen(res->pw_name)+1;
-        npasswd= strlen(res->pw_passwd)+1;
-        nage= strlen(res->pw_age)+1;
-        ncomment= strlen(res->pw_comment)+1;
-        ngecos= strlen(res->pw_gecos)+1;
-        ndir= strlen(res->pw_dir)+1;
-
-        if (nname+npasswd+nage+ncomment+ngecos+ndir
-                +strlen(res->pw_shell) < size) 
-        {
-            memcpy(s, res, sizeof(struct passwd));
-
-            strcpy(buffer, res->pw_name);
-              s->pw_name = buffer;
-            buffer += nname;
-
-            strcpy(buffer, res->pw_passwd);
-              s->pw_passwd = buffer;
-            buffer += npasswd;
-
-            strcpy(buffer, res->pw_age);
-              s->pw_age = buffer;
-            buffer += nage;
-
-            strcpy(buffer, res->pw_comment);
-              s->pw_comment = buffer;
-            buffer += ncomment;
-
-            strcpy(buffer, res->pw_gecos);
-              s->pw_gecos = buffer;
-            buffer += ngecos;
-
-            strcpy(buffer, res->pw_dir);
-              s->pw_dir = buffer;
-            buffer += ndir;
-
-            strcpy(buffer, res->pw_shell);
-              s->pw_shell = buffer;
-
-               res = s;
-        } 
-        else 
-            res = 0;
-    }  	
-      
-    pthread_mutex_unlock(&getrtl_mutex);
-
-      return res;
-}
-#endif /* defined SCO */
-
 #if !defined(FREEBSD) || (__FreeBSD_version < 601103)
 
 extern int h_errno;
