@@ -50,10 +50,12 @@
 #define vsnprintf _vsnprintf
 #endif
 
-using namespace rtl;
 using namespace osl;
 using namespace std;
 
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+
 namespace {
 
 static oslFileHandle g_aFile = 0;
