@@ -160,7 +160,7 @@ UnoInterfaceReference FactoryImpl::binuno_queryInterface(
     }
     else
     {
-        // exception occured:
+        // exception occurred:
         OSL_ENSURE(
             typelib_typedescriptionreference_isAssignableFrom(
                 ::getCppuType( reinterpret_cast<
@@ -527,13 +527,6 @@ void SAL_CALL component_getImplementationEnvironment(
     *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-sal_Bool SAL_CALL component_writeInfo(
-    void * pServiceManager, void * pRegistryKey )
-{
-    return ::cppu::component_writeInfoHelper(
-        pServiceManager, pRegistryKey, g_entries );
-}
-
 void * SAL_CALL component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * pRegistryKey )
 {
